@@ -18,6 +18,7 @@
 
 import sys
 import os
+import errno
 import argparse
 from os import listdir
 from os.path import isfile, join
@@ -175,25 +176,38 @@ def run_check_fasta(checkDir, replace, delete, concat):
 
 def check_blastdb(args):
     """ Check for outdated blastdb """
-    (query, taxon, coreTaxa_dir) = args
+    (query, taxon, coreTaxa_dir, searchTaxa_dir) = args
     blast_db = '%s/%s/%s' % (coreTaxa_dir, taxon, taxon)
     try:
         blastp_cline = NcbiblastpCommandline(query = query, db = blast_db)
         stdout, stderr = blastp_cline()
     except:
         return([query, blast_db])
-    if not os.path.exists('%s/%s/%s.fa.fai' % (coreTaxa_dir, taxon, taxon)):
-        fai_in_genome = "../../searchTaxa_dir/%s/%s.fa.fai" % (taxon, taxon)
-        fai_in_blast = "%s/%s/%s.fa.fai" % (coreTaxa_dir, taxon, taxon)
-        os.symlink(fai_in_genome, fai_in_blast)
+    fai_in_genome = "%s/%s/%s.fa.fai" % (searchTaxa_dir, taxon, taxon)
+    fai_in_blast = "%s/%s/%s.fa.fai" % (coreTaxa_dir, taxon, taxon)
+    # check if fai_in_blast is a valid symlink
+    if os.path.islink(fai_in_blast):
+        if not os.path.exists(os.readlink(fai_in_blast)):
+            if os.path.exists(fai_in_genome):
+                try:
+                    os.remove('%s/%s/%s.fa.fai' % (coreTaxa_dir, taxon, taxon))
+                except OSError as e:
+                    if e.errno != errno.ENOENT:
+                        raise
+                os.symlink(fai_in_genome, fai_in_blast)
+    # or that file doesn't exist
+    else:
+        if not os.path.exists(fai_in_blast):
+            if os.path.exists(fai_in_genome):
+                os.symlink(fai_in_genome, fai_in_blast)
 
 
-def run_check_blastdb(coreTaxa_dir, fdogPath):
+def run_check_blastdb(coreTaxa_dir, searchTaxa_dir, fdogPath):
     """ Run check_blastdb fn """
     query = '%s/data/infile.fa' % fdogPath
     jobs = []
     for fd in general_fn.read_dir(coreTaxa_dir):
-        jobs.append([query, fd, coreTaxa_dir])
+        jobs.append([query, fd, coreTaxa_dir, searchTaxa_dir])
     cpus = mp.cpu_count()-1
     pool = mp.Pool(cpus)
     out = []
@@ -216,10 +230,10 @@ def create_blastdb(args):
         shutil.rmtree(blast_path)
         ### Redo blastdb
         Path(blast_path).mkdir(parents = True, exist_ok = True)
-        blast_fn.make_blastdb([taxon, fa_file, outPath, True])
+        blast_fn.make_blastdb([taxon, fa_file, outPath, coreTaxa_dir, searchTaxa_dir, True])
         ### make symlink to fasta files
-        fa_in_genome = "../../searchTaxa_dir/%s/%s.fa" % (taxon, taxon)
-        fai_in_genome = "../../searchTaxa_dir/%s/%s.fa.fai" % (taxon, taxon)
+        fa_in_genome = "%s/%s/%s.fa" % (searchTaxa_dir, taxon, taxon)
+        fai_in_genome = "%s/%s/%s.fa.fai" % (searchTaxa_dir, taxon, taxon)
         fa_in_blast = "%s/%s.fa" % (blast_path, taxon)
         fai_in_blast = "%s/%s.fa.fai" % (blast_path, taxon)
         if not os.path.exists(fa_in_blast):
@@ -258,8 +272,10 @@ def check_complete_anno(args):
     """ Check if an annotation is complete
     I.e. if it contains annotation for all proteins of a species
     """
-    (gf,jf, annotation_dir) = args
-    cmd = 'fas.checkAnno -s %s -a %s -o %s' % (gf, jf, annotation_dir)
+    (gf,jf, annotation_dir, updateJson) = args
+    cmd = 'fas.checkAnno -s %s -a %s -o %s --noAnno' % (gf, jf, annotation_dir)
+    if updateJson:
+        cmd = '%s --update' % cmd
     try:
         subprocess.call([cmd], shell = True, stdout=subprocess.DEVNULL)
     except subprocess.CalledProcessError as e:
@@ -268,7 +284,7 @@ def check_complete_anno(args):
         sys.exit()
 
 
-def run_check_complete_anno(annotation_dir, searchTaxa_dir):
+def run_check_complete_anno(annotation_dir, searchTaxa_dir, coreTaxa_dir, updateJson):
     """ Run check_complete_anno fn """
     all_anno = [f for f in listdir(annotation_dir) if isfile(join(annotation_dir, f))]
     jobs = []
@@ -277,12 +293,16 @@ def run_check_complete_anno(annotation_dir, searchTaxa_dir):
         # print('...check annotations for %s' % tax)
         jf = '%s/%s.json' % (annotation_dir, tax)
         gf = '%s/%s/%s.fa' % (searchTaxa_dir, tax, tax)
-        jobs.append([gf,jf, annotation_dir])
+        if not os.path.exists(gf):
+            gf = '%s/%s/%s.fa' % (coreTaxa_dir, tax, tax)
+        jobs.append([gf,jf, annotation_dir, updateJson])
     cpus = mp.cpu_count()-1
     pool = mp.Pool(cpus)
     out = []
-    for _ in tqdm(pool.imap_unordered(check_complete_anno, jobs), total=len(jobs)):
-        out.append(_)
+    for i in jobs:
+        check_complete_anno(i)
+    # for _ in tqdm(pool.imap_unordered(check_complete_anno, jobs), total=len(jobs)):
+    #     out.append(_)
     return None
 
 
@@ -311,10 +331,90 @@ def check_missing_ncbiID(taxon_list):
     return(missing_taxa.keys(), dup_taxa)
 
 
-def run_check_missing_ncbiID():
-    """ Run check_missing_ncbiID fn """
-    pass
+def run_check(args):
+    (searchTaxa_dir, coreTaxa_dir, annotation_dir, replace, delete, concat, reblast, updateJson) = args
+    checkOptConflict(concat, replace, delete)
+    caution = 0
 
+    ### get fdog dir and assign searchTaxa_dir, coreTaxa_dir, annotation_dir if not given
+    fdogPath = os.path.realpath(__file__).replace('/checkData.py','')
+    if not searchTaxa_dir or not coreTaxa_dir or not annotation_dir:
+        pathconfigFile = fdogPath + '/bin/pathconfig.yml'
+        if not os.path.exists(pathconfigFile):
+            sys.exit('No pathconfig.yml found. Please run fdog.setup (https://github.com/BIONF/fDOG/wiki/Installation#setup-fdog).')
+        cfg = general_fn.load_config(pathconfigFile)
+        try:
+            dataPath = cfg['dataPath']
+        except:
+            dataPath = os.getcwd()
+
+        if not searchTaxa_dir:
+            try:
+                searchTaxa_dir = cfg['searchpath']
+            except:
+                searchTaxa_dir = dataPath + '/searchTaxa_dir'
+        if not coreTaxa_dir:
+            try:
+                coreTaxa_dir = cfg['corepath']
+            except:
+                coreTaxa_dir = dataPath + "/coreTaxa_dir"
+        if not annotation_dir:
+            try:
+                annotation_dir = cfg['annopath']
+            except:
+                annotation_dir = dataPath + "/annotation_dir"
+
+    searchTaxa_dir = os.path.abspath(searchTaxa_dir)
+    coreTaxa_dir = os.path.abspath(coreTaxa_dir)
+    annotation_dir = os.path.abspath(annotation_dir)
+
+    ### check searchTaxa_dir
+    print('=> Checking %s...' % searchTaxa_dir)
+    search_taxa = run_check_fasta(searchTaxa_dir, replace, delete, concat)
+
+    ### check coreTaxa_dir
+    if reblast:
+        print('=> (Re-)Creating blastDBs...')
+        failed_blast = run_create_blastdb(coreTaxa_dir, searchTaxa_dir)
+        if len(failed_blast) > 0:
+            print('*** WARNING: Some BlastDBs cannot be created:\n%s' % ', '.join(failed_blast))
+        else:
+            print('All old BlastDBs have been updated!')
+    print('=> Checking %s...' % coreTaxa_dir)
+    core_taxa = run_check_fasta(coreTaxa_dir, replace, delete, concat)
+    check_blast = run_check_blastdb(coreTaxa_dir, searchTaxa_dir, fdogPath)
+
+    if not check_blast[0] == 1:
+        print('*** ERROR: Version incompatible between BlastDB and BLAST program!')
+        print('For checking, run: blastp -query %s -db %s' % (check_blast[0], check_blast[1]))
+        print('Consider using --reblast option to update old BlastDBs!')
+        sys.exit()
+
+    ### check annotation_dir
+    print('=> Checking %s...' % annotation_dir)
+    missing_anno = check_missing_json(annotation_dir, general_fn.join_2lists(search_taxa, core_taxa))
+    if len(missing_anno) > 0:
+        print('\033[92m*** WARNING: Annotation files not found for:\033[0m')
+        print(*missing_anno, sep = "\n")
+        print('NOTE: You still can run fdog without FAS using the option "-fasoff"')
+        caution = 1
+    run_check_complete_anno(annotation_dir, searchTaxa_dir, coreTaxa_dir, updateJson)
+
+    ### check ncbi IDs
+    print('=> Checking NCBI taxonomy IDs...')
+    missing_taxa, dup_taxa = check_missing_ncbiID(general_fn.join_2lists(search_taxa, core_taxa))
+    if (len(missing_taxa) > 0):
+        print('\033[92m*** WARNING: Taxa not found in current local NCBI taxonomy database:\033[0m')
+        print(*missing_taxa, sep = "\n")
+        print('==> NOTE: You still can run fDOG with those taxa, but they will not be included in the core set compilation!')
+        caution = 1
+    if (len(dup_taxa) > 0):
+        print('\033[92m*** WARNING: These taxa have the same NCBI taxonomy IDs:\033[0m')
+        print(*dup_taxa, sep = "\n")
+        print('==> NOTE: This could lead to some conflicts!')
+        caution = 1
+    print('---------------------------------')
+    return(caution)
 
 def main():
     version = get_distribution('fdog').version
@@ -326,6 +426,7 @@ def main():
     parser.add_argument('--delete', help='Delete special characters in sequences', action='store_true', default=False)
     parser.add_argument('--concat', help='Concatenate multiple-line sequences into single-line', action='store_true', default=False)
     parser.add_argument('--reblast', help='Re-create blast databases', action='store_true', default=False)
+    parser.add_argument('--updateJson', help='Update annotation json file to FAS >=1.16', action='store_true', default=False)
 
     ### get arguments
     args = parser.parse_args()
@@ -337,80 +438,14 @@ def main():
     delete = args.delete
     concat = args.concat
     reblast = args.reblast
+    updateJson = args.updateJson
 
-    checkOptConflict(concat, replace, delete)
-    caution = 0
-
-    ### get fdog dir and assign searchTaxa_dir, coreTaxa_dir, annotation_dir if not given
-    fdogPath = os.path.realpath(__file__).replace('/checkData.py','')
-    if not searchTaxa_dir or not coreTaxa_dir or not annotation_dir:
-        pathconfigFile = fdogPath + '/bin/pathconfig.txt'
-        if not os.path.exists(pathconfigFile):
-            sys.exit('No pathconfig.txt found. Please run fdog.setup (https://github.com/BIONF/fDOG/wiki/Installation#setup-fdog).')
-        with open(pathconfigFile) as f:
-            dataPath = f.readline().strip()
-        if not searchTaxa_dir:
-            searchTaxa_dir = dataPath + "/searchTaxa_dir"
-        if not coreTaxa_dir:
-            coreTaxa_dir = dataPath + "/coreTaxa_dir"
-        if not annotation_dir:
-            annotation_dir = dataPath + "/annotation_dir"
-
-    searchTaxa_dir = os.path.abspath(searchTaxa_dir)
-    coreTaxa_dir = os.path.abspath(coreTaxa_dir)
-    annotation_dir = os.path.abspath(annotation_dir)
-
-    ### check searchTaxa_dir
-    print('=> Checking %s...' % searchTaxa_dir)
-    genomeTaxa = run_check_fasta(searchTaxa_dir, replace, delete, concat)
-
-    ### check coreTaxa_dir
-    if reblast:
-        print('=> (Re-)Creating blastDBs...')
-        failed_blast = run_create_blastdb(coreTaxa_dir, searchTaxa_dir)
-        if len(failed_blast) > 0:
-            print('*** WARNING: Some BlastDBs cannot be created:\n%s' % ', '.join(failed_blast))
-        else:
-            print('All old BlastDBs have been updated!')
-    print('=> Checking %s...' % coreTaxa_dir)
-    blastTaxa = run_check_fasta(coreTaxa_dir, replace, delete, concat)
-    check_blast = run_check_blastdb(coreTaxa_dir, fdogPath)
-
-    if not check_blast[0] == 1:
-        print('*** ERROR: Version incompatible between BlastDB and BLAST program!')
-        print('For checking, run: blastp -query %s -db %s' % (check_blast[0], check_blast[1]))
-        print('Consider using --reblast option to update old BlastDBs!')
-        sys.exit()
-
-    ### check annotation_dir
-    print('=> Checking %s...' % annotation_dir)
-    missing_anno = check_missing_json(annotation_dir, general_fn.join_2lists(genomeTaxa, blastTaxa))
-    if len(missing_anno) > 0:
-        print('\033[92m*** WARNING: Annotation files not found for:\033[0m')
-        print(*missing_anno, sep = "\n")
-        print('NOTE: You still can run fdog without FAS using the option "-fasoff"')
-        caution = 1
-    run_check_complete_anno(annotation_dir, searchTaxa_dir)
-
-    # ### check ncbi IDs
-    print('=> Checking NCBI taxonomy IDs...')
-    missing_taxa, dup_taxa = check_missing_ncbiID(general_fn.join_2lists(genomeTaxa, blastTaxa))
-    if (len(missing_taxa) > 0):
-        print('\033[92m*** WARNING: Taxa not found in current local NCBI taxonomy database:\033[0m')
-        print(*missing_taxa, sep = "\n")
-        print('==> NOTE: You still can run fDOG with those taxa, but they will not be included in the core set compilation!')
-        caution = 1
-    if (len(dup_taxa) > 0):
-        print('\033[92m*** WARNING: These taxa have the same NCBI taxonomy IDs:\033[0m')
-        print(*dup_taxa, sep = "\n")
-        print('==> NOTE: This could lead to some conflicts!')
-        caution = 1
-
-    print('---------------------------------')
+    caution = run_check([searchTaxa_dir, coreTaxa_dir, annotation_dir, replace, delete, concat, reblast, updateJson])
     if caution == 1:
         print('==> Done! Data are ready to use WITH CAUTION!')
     else:
         print('==> Done! Data are ready to use!')
 
+
 if __name__ == '__main__':
     main()
