@@ -19,6 +19,7 @@ import sys
 import os
 from ete3 import NCBITaxa
 
+import fdog.libs.zzz as general_fn
 
 def getNcbiName(taxonName):
     ncbi = NCBITaxa()
@@ -33,23 +34,37 @@ def getNcbiName(taxonName):
 def getTaxa():
     # get data path
     fdogPath = os.path.realpath(__file__).replace('/showTaxa.py','')
-    pathconfigFile = fdogPath + '/bin/pathconfig.txt'
+    pathconfigFile = fdogPath + '/bin/pathconfig.yml'
     if not os.path.exists(pathconfigFile):
-        sys.exit('No pathconfig.txt found. Please run fdog.setup (https://github.com/BIONF/fDOG/wiki/Installation#setup-fdog).')
+        sys.exit('No pathconfig.yml found. Please run fdog.setup (https://github.com/BIONF/fDOG/wiki/Installation#setup-fdog).')
     with open(pathconfigFile) as f:
-        dataPath = f.readline().strip()
+        cfg = general_fn.load_config(pathconfigFile)
+        try:
+            dataPath = cfg['datapath']
+        except:
+            dataPath = 'several places!'
+        try:
+            corepath = cfg['corepath']
+        except:
+            corepath = dataPath + '/coreTaxa_dir'
+        general_fn.check_file_exist(corepath)
+        try:
+            searchpath = cfg['searchpath']
+        except:
+            searchpath = dataPath + '/searchTaxa_dir'
+        general_fn.check_file_exist(searchpath)
 
     # print taxa in coreTaxa_dir
     print('##### Data found at %s' % dataPath)
     print('\n##### Taxa in the core sets, which can be used as reference species #####\n')
-    for taxon in sorted(os.listdir(dataPath + '/coreTaxa_dir/')):
-        if os.path.isdir(dataPath + '/coreTaxa_dir/' + taxon):
+    for taxon in sorted(os.listdir(corepath)):
+        if os.path.isdir(f'{corepath}/{taxon}'):
             print('%s\t%s' % (taxon, getNcbiName(taxon)))
 
     # print taxa in searchTaxa_dir
     print('\n##### Search taxa. in which you can search orthologs #####\n')
-    for taxon in sorted(os.listdir(dataPath + '/searchTaxa_dir/')):
-        if os.path.isdir(dataPath + '/searchTaxa_dir/' + taxon):
+    for taxon in sorted(os.listdir(searchpath)):
+        if os.path.isdir(f'{searchpath}/{taxon}'):
             print('%s\t%s' % (taxon, getNcbiName(taxon)))
 
 
